@@ -1,7 +1,7 @@
 %%%-------------------------------------------------------------------
 %%% Created : 22 Sep 2018 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
-%%% Copyright (C) 2002-2022 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2024 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -28,7 +28,7 @@
 -export([get_cert_info/1]).
 %% gen_server callbacks
 -export([init/1, handle_call/3, handle_cast/2, handle_info/2,
-	 terminate/2, code_change/3, format_status/2]).
+	 terminate/2, code_change/3]).
 %% For tests only
 -export([get_expiration_date/1, current_datetime/0, extract_domains/1]).
 
@@ -244,7 +244,9 @@ format_error({invalid_cert, Line, Unknown}) ->
     at_line(Line, io_lib:format("~w", [Unknown]));
 format_error(Posix) when is_atom(Posix) ->
     case file:format_error(Posix) of
-	"unknown POSIX error" ->
+	"unknown POSIX error" -> % Erlang/OTP 25 and older
+	    atom_to_list(Posix);
+	[$u, $n, $k, $n, $o, $w, $n | _] -> % Erlang/OTP 26 and newer
 	    atom_to_list(Posix);
 	Reason ->
 	    Reason
@@ -326,10 +328,6 @@ terminate(_Reason, State) ->
 code_change(_OldVsn, State, _Extra) ->
     {ok, State}.
 
--spec format_status(normal | terminate, list()) -> term().
-format_status(_Opt, Status) ->
-    Status.
-
 %%%===================================================================
 %%% Certificate file loading/unloading
 %%%===================================================================
